package com.dgtly.order.controller;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.exception.base.BaseException;
import com.dgtly.common.utils.MapDataUtil;
import com.dgtly.order.domain.OrderDetailModel;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.dgtly.common.core.controller.BaseController;
import org.springframework.web.client.RestTemplate;

import javax.servlet.http.HttpServletRequest;

/**
 * 订单基础 订单的基础信息Controller
 * 
 * @author qxp
 * @date 2020-07-10
 */
@Controller
@RequestMapping("/order/orderbase")
public class OrderBaseController extends BaseController {
    private String prefix = "order/orderbase";

    @Autowired
    private RestTemplate restTemplate;

    @Value(value = "${ruoyi.cloudPath}")
    private String cloudPath;


    @RequiresPermissions("order:orderbase:view")
    @GetMapping()
    public String orderbase() {
        return prefix + "/orderbase";
    }

    /**
     * 查询订单基础 订单的基础信息列表
     */
    @RequiresPermissions("order:orderbase:list")
    @PostMapping("/list")
    @ResponseBody
    public Object list(HttpServletRequest request) {
        String str = "";

        String url = cloudPath + "order"+"/order/meta-hana-sales-order/list";

        try{
            //设置为form方式
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
            MultiValueMap<String, Object> map = MapDataUtil.convertMultiValueMap(request);
            HttpEntity<Object> requestEntity
                    = new HttpEntity<>(map, headers);
            str = restTemplate.postForObject(url, requestEntity, String.class);
        }catch(Exception e){
            logger.error("查询基础订单列表报错"+url,e);
            throw e;
        }
         return str;
    }


    /**
     * 修改订单基础 订单的基础信息
     */
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        String url = cloudPath + "order"+"/order/meta-hana-sales-order/orderLineDetail?orderNumber=" + id;
        //String url = "http://10.32.2.212:8000/" + "order"+"/order/meta-hana-sales-order/orderLineDetail?orderNumber=" + id;
        String str= "";
        try{
            str = restTemplate.getForObject(url, String.class);
            JSONObject json = JSONObject.parseObject(str);
            if(json.getInteger("code")==200){

                mmap.put("orderBase", json.getObject("data",OrderDetailModel.class));
            }else{
                throw new BaseException("order",json.getString("message"));
            }
        }catch(Exception e){
            logger.error("查询基础订单详情报错"+url,e);
            throw e;
        }

        return prefix + "/edit";
    }
}


