package com.dgtly.wxportal.controller;

import com.alibaba.fastjson.JSONObject;
import com.dgtly.common.annotation.ApiPassToken;
import com.dgtly.common.core.controller.ApiBaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.domain.ParameterObject;
import com.dgtly.common.utils.http.HttpUtils;
import com.dgtly.common.utils.security.EncryptPassWordClass;
import com.dgtly.wxportal.domain.WxBanner;
import com.dgtly.wxportal.domain.WxMagnet;
import com.dgtly.wxportal.utils.qywxutils.QyWxSendMessageUtil;
import com.dgtly.wxportal.utils.qywxutils.QyWxUserUtil;
import com.dgtly.common.utils.RedisUtil;
import com.dgtly.system.domain.SysUser;
import com.dgtly.wxportal.domain.WxQyUser;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.service.IWxQyUserService;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextCard;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextCardMessage;
import com.dgtly.wxportal.utils.qywxutils.messageModel.QyWxTextMessage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


@Api(tags = "企业微信相关API", description = "提供企业微信相关的AP")
@RequestMapping("wx")
@RestController
@ApiPassToken
public class WxController extends ApiBaseController {


    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private QyWxUserUtil qyWxUserUtil;

    @Autowired
    private IWxQyUserService wxQyUserService;
    @Autowired
    private ISysUserService sysUserService;

    @Autowired
    private QyWxSendMessageUtil qyWxSendMessageUtil;

    @Value(value = "${libang.getUserByTicket}")
    private String getUserByTicketUrl;


    @ApiOperation(value = "获取微信授权跳转url",notes = "参数：{url:www.baidu.com}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("getOauthUrl")
    public Object getOauthUrl(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("url");
        String oauth2Url =  qyWxUserUtil.getOauth2Url(obj.getString("url"),null);
        return AjaxResult.success().putKV("oauth2Url",oauth2Url);
    }

    @ApiOperation(value = "根据微信coed获取用户信息",
            notes = "参数：{code:123} code微信跳转回来的携带的用户code" +
                    "错误：301 当前用户不是当前企业用户成员" +
                    "错误：302 当前用户不属于DIY用户或经销商用户")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("getWxUserInfo")
    public Object getWxUserInfo(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("code");
        String code = obj.getString("code");
        JSONObject json =  qyWxUserUtil.getUserId(code);
        String userId ="";
        if(!json.containsKey("UserId")){
            return AjaxResult.error(301,"当前用户不是企业成员");
        }
        userId = json.getString("UserId");
        SysUser user = sysUserService.selectUserByLoginName(userId);
        if(user==null){
            return AjaxResult.error(302,"当前用户不属于DIY用户或经销商用户");
        }else{
            return AjaxResult.success().putKV("sysUser",user);
        }
    }



    @ApiOperation(value = "根据用户userId发送文本",
            notes = "参数：{userId:123," +
                    "content:\"XXXXXXXXXXXXXXXXXX\"} " +
                    "错误：301 当前用户未绑定企业微信")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("sendTextMessage")
    public Object sendTextMessage(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId,content");
        String userId = obj.getString("userId");
        WxQyUser wxQyUser = wxQyUserService.selectWxQyUserBySysUserId(userId);
        if(wxQyUser==null){
            logger.error("发送企业微信细信息对象为空");
            return AjaxResult.error(301,"发送对象位绑定企业微信");
        }
        QyWxTextMessage qyWxTextMessage = new QyWxTextMessage();
        qyWxTextMessage.setTouser(wxQyUser.getUserid());
        qyWxTextMessage.setText(obj.getString("content"));

        qyWxSendMessageUtil.sendMessage(qyWxTextMessage);
        return AjaxResult.success();
    }

    @ApiOperation(value = "根据用户userId发送文本card",
            notes = "参数：{userId:123," +
                    "title:\"标题，不超过128个字节\"," +
                    "description:\"描述，不超过512个字节\"" +
                    "url:\"点击后跳转的链接。\"," +
                    "btntxt:\"按钮文字。 默认为“详情”， 不超过4个文字\"} " +
                    "错误：301 当前用户未绑定企业微信")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("sendTextCardMessage")
    public Object sendTextCardMessage(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId,title,description,url");
        String userId = obj.getString("userId");

        QyWxTextCard tc = obj.parseBean(QyWxTextCard.class);

        WxQyUser wxQyUser = wxQyUserService.selectWxQyUserBySysUserId(userId);
        if(wxQyUser==null){
            logger.error("发送企业微信细信息对象为空");
            return AjaxResult.error(301,"发送对象位绑定企业微信");
        }
        QyWxTextCardMessage q = new QyWxTextCardMessage();

        q.setTouser(wxQyUser.getUserid());
        q.setTextcard(tc);
        qyWxSendMessageUtil.sendMessage(q);
        return AjaxResult.success();
    }

    @ApiOperation(value = "根据立邦微信基建返回的Ticket获取用户信息",notes = "参数：{'Ticket':1}=" +
            " 错误：301 根据Ticket获取用户信息失败" +
            "错误：302 当前用户可能不属于此企业" +
            "错误：303 当前用户可能不属于DIY人员")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("/getUserByTicket")
    public Object getUserByTicket(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("Ticket");
        JSONObject json  =new JSONObject();
        json.put("Ticket",obj.getString("Ticket"));
        String res = HttpUtils.sendJsonPost(getUserByTicketUrl,json);
        logger.info("根据Ticket获取的用户信息为{}",res);
        json = JSONObject.parseObject(res);
        if(json.containsKey("Code")&&json.getInteger("Code")==0){
            if(json.containsKey("Data")&&json.getJSONObject("Data")!=null){
                json =  json.getJSONObject("Data");
                if(json.containsKey("Number")&&json.getString("Number")!=null&&!json.getString("Number").trim().equals("")){
                    String emplyeeId = json.getString("Number");
                    SysUser user = sysUserService.selectUserByEmplyeeId(emplyeeId);
                    if(user!=null){
                        return AjaxResult.success().putKV("sysUser",user);
                    }else{
                        return AjaxResult.error(303,"当前用户可能不是DIY人员");
                    }
                }else{
                    return AjaxResult.error(302,"当前用户可能不属于此企业");
                }
            }
        }
        return AjaxResult.error(301,"根据Ticket获取用户信息失败");
    }

    @ApiOperation(value = "根据账户密码获取用户权限",notes = "参数：{'username':'1','password':'xxx'}" +
            " 错误：301 密码错误" +
            "错误：302  查无此人")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("/getUserByPassWord")
    public Object getUserByPassWord(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("username,password");
        String username = obj.getString("username");
        String password = obj.getString("password");
        SysUser user = sysUserService.selectUserByLoginName(username);
        if(user==null){
            return AjaxResult.error(302,"查无此人");
        }
        String pass = EncryptPassWordClass.encryptPassword(user.getLoginName(),password,user.getSalt());
        if(pass.equals(user.getPassword())){
            return AjaxResult.success().putKV("sysUser",user);
        }else{
            return AjaxResult.error(301,"密码错误");
        }
    }


}
